@@ -122,19 +122,17 @@ function show_headers_options_save() {
       foreach($show_header_array as $key => $header) {
         if (strlen($header) == 0) {
           unset($show_header_array[$key]);
-        } else {
-          if (substr($header, -1, 1) != ":") {
-            $show_header_array[$key] .= ":";
-          }
         }
       }
 
       if (count($show_header_array) == 0) {
-        unset($GLOBAL['show_header_array']);
+        unset($show_header_array);
       }
     } else {
-      unset($GLOBALS['show_header_array']);
+      unset($show_header_array);
     }
+  } else {
+    unset($show_header_array);
   }
 
   if (isset($show_header_array)) {
